auth0_flutter_platform_interface library

Classes

Account
AndroidCredentialsConfiguration
Configuration options for the Android platform that can be set while instantiating the CredentialsManager.
ApiRequest<TOptions extends RequestOptions>
Auth0FlutterAuthPlatform
Auth0FlutterDPoPPlatform
Platform interface for DPoP (Demonstrating Proof-of-Possession) operations.
Auth0FlutterWebAuthPlatform
Auth0FlutterWebPlatform
AuthCustomTokenExchangeOptions
AuthDPoPHeadersOptions
AuthLoginOptions
AuthLoginWithCodeOptions
AuthLoginWithOtpOptions
AuthMultifactorChallengeOptions
AuthPasswordlessLoginOptions
AuthRenewOptions
AuthResetPasswordOptions
AuthSignupOptions
AuthSSOExchangeOptions
Options used to call Auth0FlutterAuthPlatform.ssoExchange().
AuthUserInfoOptions
BaseRequest<TOptions extends RequestOptions?>
Challenge
A multi-factor challenge.
ClientOptions
The options for the underlying SDK on the web platform.
Credentials
A collection of authentication artifacts obtained from Auth0 when a user logs in.
CredentialsManagerConfiguration
Class used to set platform-specific configuration for CredentialsManager in the SDK.
CredentialsManagerPlatform
The interface that implementations of CredentialsManager must implement.
CredentialsManagerRequest<TOptions extends RequestOptions?>
CredentialsOptions
DatabaseUser
DPoPHeaders
DPoPRequest<TOptions>
Request object for DPoP utility operations.
EmptyRequestOptions
ExchangeTokenOptions
Options for custom token exchange on web platforms.
GetCredentialsOptions
Options used to retrieve Credentials using the CredentialsManagerPlatform.
GetSSOCredentialsOptions
Options used to retrieve SSOCredentials via CredentialsManagerPlatform.getSSOCredentials().
HasValidCredentialsOptions
Options used to check if a non-expired pair of Credentials can be obtained using the CredentialsManagerPlatform.
IdTokenValidationConfig
Configuration settings for ID token validation.
IOSCredentialsConfiguration
Configuration options for the iOS platform that can be set while instantiating the CredentialsManager. It can be used to set the keychain store key,access group and accessibility level for the stored credentials.
LocalAuthentication
Settings for local authentication prompts.
LoginOptions
LogoutOptions
MethodChannelAuth0FlutterAuth
MethodChannelAuth0FlutterDPoP
Method channel implementation of Auth0FlutterDPoPPlatform.
MethodChannelAuth0FlutterWebAuth
MethodChannelCredentialsManager
Method Channel implementation to communicate with the Native CredentialsManager
PopupLoginOptions
RenewCredentialsOptions
Options to renew Credentials using the CredentialsManagerPlatform.
SafariViewController
Configuration for using SFSafariViewController on iOS.
SaveCredentialsOptions
Options used to save Credentials using the CredentialsManagerPlatform.
SSOCredentials
Authentication artifacts used to establish a web session from a native application context (Native to Web SSO).
StubAuth0FlutterWeb
UserAgent
UserProfile
A collection of properties that represents the authenticated user, extracted from ID token claims.
WebAuthLoginOptions
WebAuthLogoutOptions
WebAuthRequest<TOptions extends RequestOptions>

Enums

Accessibility
The accessibility level for the credentials on iOS.
CacheLocation
The location where cached data is stored by the underlying SDK on the web platform.
CacheMode
How the cache is to be used when requesting new tokens silently.
ChallengeType
How the user will get the multi-factor authentication challenge and prove possession.
LocalAuthenticationLevel
The level of authentication required.
PasswordlessType
Types of passwordless authentication.
SafariViewControllerPresentationStyle
Presentation styles for when using SFSafariViewController on iOS. For the full description of what each option does, please see the UIModelPresentationStyle docs.

Exceptions / Errors

ApiException
Auth0Exception
CredentialsManagerException
Exception thrown by MethodChannelCredentialsManager when something goes wrong.
WebAuthenticationException
WebException
Exception thrown by Auth0FlutterWebPlatform when something goes wrong.