AuthCustomTokenExchangeOptions class

Implemented types

Constructors

AuthCustomTokenExchangeOptions({required String subjectToken, required String subjectTokenType, String? audience, Set<String> scopes = const {}, String? organization})
const

Properties

audience String?
final
hashCode int
The hash code for this object.
no setterinherited
organization String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes Set<String>
final
subjectToken String
final
subjectTokenType String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited