CredentialsManagerException class

Exception thrown by MethodChannelCredentialsManager when something goes wrong.

Inheritance

Properties

code String
finalinherited
details Map<String, dynamic>
finalinherited
hashCode int
The hash code for this object.
no setterinherited
isNoCredentialsFound bool
no setter
isNoRefreshTokenFound bool
no setter
isRetryable bool
Whether the error is transient and the operation can be retried. When true, the failure is likely due to a temporary condition such as a network outage. When false, the failure is permanent (e.g. an invalid refresh token) and the user should be logged out instead.
no setter
isTokenRenewFailed bool
no setter
message String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited