CredentialsManagerException class
Exception thrown by MethodChannelCredentialsManager when something goes wrong.
- Inheritance
-
- Object
- Auth0Exception
- CredentialsManagerException
Constructors
-
CredentialsManagerException(String code, String message, Map<
String, dynamic> details) -
const
- CredentialsManagerException.fromPlatformException(PlatformException e)
-
Fectory method that transforms a PlatformException to a
CredentialsManagerException.
factory
- CredentialsManagerException.unknown(String message)
-
const
Properties
- code → String
-
finalinherited
-
details
→ Map<
String, dynamic> -
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- isNoCredentialsFound → bool
-
no setter
- isNoRefreshTokenFound → bool
-
no setter
- isRetryable → bool
-
Whether the error is transient and the operation can be retried.
When
true, the failure is likely due to a temporary condition such as a network outage. Whenfalse, the failure is permanent (e.g. an invalid refresh token) and the user should be logged out instead.no setter - isTokenRenewFailed → bool
-
no setter
- message → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited